@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2005 Olivier Goffart <ogoffart at kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2005 Olivier Goffart <ogoffart at kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KNOTIFYEVENTLIST_H
@@ -34,15 +23,17 @@ class KNotifyEventList : public QTreeWidget
 {
     Q_OBJECT
 public:
-    KNotifyEventList(QWidget *parent);
-    ~KNotifyEventList();
+    explicit KNotifyEventList(QWidget *parent);
+    ~KNotifyEventList() override;
     void fill(const QString &appname, const QString &context_name = QString(),
               const QString &context_value = QString(), bool loadDefaults = false);
     void save();
     void updateCurrentItem();
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    void updateAllItems();
+    QSize sizeHint() const override;
 
     void selectEvent(const QString &eventId);
+    bool disableAllSounds();
 
 private:
     KConfig *config;
